/****************************************************************************
 *                                                                          *
 * Header file, describing data in a FLI file                               *
 * FLI Player                                                               *
 * By TH/21/1/97                                                            *
 *                                                                          *
 ****************************************************************************/

#include <stdio.h>
#include <stdlib.h>
#include <memory.h>
#include <dos.h>
#include <i86.h>

typedef unsigned char   UBYTE;
typedef signed char     SBYTE;
typedef unsigned short  WORD;
typedef signed short    SWORD;
typedef unsigned long   DWORD;
typedef signed long     LONG;


typedef enum flichunks {
        FLI_COLOR       = 11,
        FLI_LC          = 12,
        FLI_BLACK       = 13,
        FLI_BRUN        = 15,
        FLI_COPY        = 16,
        FLI_DELTA       = 7,
        FLI_256_COLOR   = 4
} FLICHUNKS;


typedef enum bool {
	FALSE = 0,
	TRUE = -1
} BOOL;


#pragma pack(1)
typedef struct flihdr {
        DWORD           size;
        WORD            magic;
        WORD            frames;
        WORD            width;
        WORD            height;
        WORD            depth;
        WORD            flags;
        WORD            speed;
        DWORD           next;
        DWORD           frit;
        UBYTE           expand[102];
} FLIHDR;
#pragma pack()

#pragma pack(1)
typedef struct fliframe {
        DWORD           size;
        WORD            magic;
        SWORD           chunks;
        UBYTE           expand[8];
} FLIFRAME;
#pragma pack()

#pragma pack(1)
typedef struct flichunk {
        DWORD           size;
        WORD            type;
} FLICHUNK;
#pragma pack()

typedef struct flipalette {
        UBYTE           r;
        UBYTE           g;
        UBYTE           b;
        UBYTE           a;      /* for alignment purposes */
} FLIPALETTE;

/****************************************************************************/

void                    *OpenFLIFile(UBYTE *filename);
void                    ProcessColorChunk(UBYTE *src);
void                    ProcessLcChunk(UBYTE *src);
void                    ProcessBlackChunk(UBYTE *src);
void                    ProcessBrunChunk(UBYTE *src);
void                    ProcessCopyChunk(UBYTE *src);
void                    ProcessDeltaChunk(UBYTE *src);
void                    Process256ColorChunk(UBYTE *src);
BOOL			ProcessFrame(FLIFRAME *frame);



